Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1236)

Unified Diff: build/android/pylib/gtest/test_package.py

Issue 18770008: [Android] Redesigns the sharder to allow replicated vs distributed tests (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Re-adds -f short form to gtest_filter switch Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/pylib/gtest/setup.py ('k') | build/android/pylib/gtest/test_package_apk.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/pylib/gtest/test_package.py
diff --git a/build/android/pylib/gtest/test_package.py b/build/android/pylib/gtest/test_package.py
index 4cccea104c7fc48854fa071995debc432c965948..945b4fde947c97ff3a258a146c22bd77881a9c20 100644
--- a/build/android/pylib/gtest/test_package.py
+++ b/build/android/pylib/gtest/test_package.py
@@ -15,18 +15,24 @@ class TestPackage(object):
Args:
adb: ADB interface the tests are using.
device: Device to run the tests.
- test_suite: A specific test suite to run, empty to run all.
+ suite_path_full: Absolute path to a specific test suite to run,
+ empty to run all.
+ Ex: '/foo/bar/base_unittests-debug.apk', for which
+ self.suite_path_full = '/foo/bar/base_unittests-debug.apk'
+ self.suite_path = '/foo/bar/base_unittests-debug'
+ self.suite_basename = 'base_unittests'
+ self.suite_dirname = '/foo/bar'
tool: Name of the Valgrind tool.
"""
- def __init__(self, adb, device, test_suite, tool):
+ def __init__(self, adb, device, suite_path_full, tool):
self.adb = adb
self.device = device
- self.test_suite_full = test_suite
- self.test_suite = os.path.splitext(test_suite)[0]
- self.test_suite_basename = self._GetTestSuiteBaseName()
- self.test_suite_dirname = os.path.dirname(
- self.test_suite.split(self.test_suite_basename)[0])
+ self.suite_path_full = suite_path_full
+ self.suite_path = os.path.splitext(suite_path_full)[0]
+ self.suite_basename = self._GetTestSuiteBaseName()
+ self.suite_dirname = os.path.dirname(
+ self.suite_path.split(self.suite_basename)[0])
self.tool = tool
def ClearApplicationState(self):
« no previous file with comments | « build/android/pylib/gtest/setup.py ('k') | build/android/pylib/gtest/test_package_apk.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698